Package: RNetLogo
Version: 1.0-4
Date: 2017-06-10
Title: Provides an Interface to the Agent-Based Modelling Platform
        'NetLogo'
Author: Jan C. Thiele
Maintainer: Jan C. Thiele <rnetlogo@gmx.de>
Description: Interface to use and access Wilensky's 'NetLogo' (Wilensky 1999) from R using either headless (no GUI) or interactive GUI mode. Provides functions to load models, execute commands, and get values from reporters. Mostly analogous to the 'NetLogo' 'Mathematica' Link <https://github.com/NetLogo/Mathematica-Link>.
Depends: R (>= 3.3.2), rJava (>= 0.9-8), igraph
Suggests: parallel
SystemRequirements: Java (>= 8.0), NetLogo (>= 6.0)
License: GPL-2
LazyLoad: yes
URL: http://rnetlogo.r-forge.r-project.org/
NeedsCompilation: no
Packaged: 2017-06-10 13:46:08 UTC; jthiele
Repository: CRAN
Date/Publication: 2017-06-10 15:57:07 UTC
Built: R 4.6.0; ; 2026-04-26 03:31:58 UTC; unix
