importFrom("rJava", ".jarray", ".jcall", ".jevalArray",
           ".jinit", ".jnew", ".jpackage", ".jgetEx", 
           ".jcheck")
importFrom("igraph", "graph.data.frame")

export("NLStart", "NLLoadModel", "NLSourceFromString", "NLCommand", "NLDoCommand", 
	 "NLDoCommandWhile", "NLReport", "NLDoReport", "NLDoReportWhile", 
	 "NLGetPatches", "NLSetPatches", "NLSetPatchSet", "NLSetAgentSet", "NLGetAgentSet", "NLGetGraph", "NLDfToList", "NLQuit")
